Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1167)

Unified Diff: webkit/api/public/WebDevToolsAgentClient.h

Issue 287009: Move WebDevToolsAgent{Delegate} into the WebKit API.... (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: '' Created 11 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « webkit/api/public/WebDevToolsAgent.h ('k') | webkit/api/public/WebFrame.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webkit/api/public/WebDevToolsAgentClient.h
===================================================================
--- webkit/api/public/WebDevToolsAgentClient.h (revision 29289)
+++ webkit/api/public/WebDevToolsAgentClient.h (working copy)
@@ -1,35 +1,59 @@
-// Copyright (c) 2009 The Chromium Authors. All rights reserved.
-// Use of this source code is governed by a BSD-style license that can be
-// found in the LICENSE file.
+/*
+ * Copyright (C) 2009 Google Inc. All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are
+ * met:
+ *
+ * * Redistributions of source code must retain the above copyright
+ * notice, this list of conditions and the following disclaimer.
+ * * Redistributions in binary form must reproduce the above
+ * copyright notice, this list of conditions and the following disclaimer
+ * in the documentation and/or other materials provided with the
+ * distribution.
+ * * Neither the name of Google Inc. nor the names of its
+ * contributors may be used to endorse or promote products derived from
+ * this software without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+ * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+ * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
+ * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
+ * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
+ * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+ * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
+ * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+ * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
+ * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ */
-#ifndef WEBKIT_GLUE_WEBDEVTOOLSAGENT_DELEGATE_H_
-#define WEBKIT_GLUE_WEBDEVTOOLSAGENT_DELEGATE_H_
+#ifndef WebDevToolsAgentClient_h
+#define WebDevToolsAgentClient_h
-#include "base/basictypes.h"
+#include "WebCommon.h"
namespace WebKit {
class WebString;
-}
-class WebDevToolsAgentDelegate {
- public:
- WebDevToolsAgentDelegate() {}
- virtual ~WebDevToolsAgentDelegate() {}
+class WebDevToolsAgentClient {
+public:
+ virtual void sendMessageToFrontend(const WebString& className,
+ const WebString& methodName,
+ const WebString& param1,
+ const WebString& param2,
+ const WebString& param3) = 0;
- virtual void SendMessageToClient(const WebKit::WebString& class_name,
- const WebKit::WebString& method_name,
- const WebKit::WebString& param1,
- const WebKit::WebString& param2,
- const WebKit::WebString& param3) = 0;
+ // Invalidates widget which leads to the repaint.
+ virtual void forceRepaint() = 0;
- // Invalidates widget which leads to the repaint.
- virtual void ForceRepaint() = 0;
+ // Returns the identifier of the entity hosting this agent.
+ virtual int hostIdentifier() = 0;
- // Returns the id of the entity hosting this agent.
- virtual int GetHostId() = 0;
-
- private:
- DISALLOW_COPY_AND_ASSIGN(WebDevToolsAgentDelegate);
+protected:
+ ~WebDevToolsAgentClient() {}
};
-#endif // WEBKIT_GLUE_WEBDEVTOOLSAGENT_DELEGATE_H_
+} // namespace WebKit
+
+#endif
« no previous file with comments | « webkit/api/public/WebDevToolsAgent.h ('k') | webkit/api/public/WebFrame.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698